@@ -3,17 +3,19 @@
 #' from surfaces to an ASCII file and reads it in.
 #' @param file (character) input filename of curvature measure
 #' @param outfile (character) output filename (if wanted to be saved)
+#' @param ... Additional arguments to pass to \code{\link{fs_cmd}}
 #' @return \code{data.frame}
 #' @export
-#' @examples 
+#' @examples
 #' if (have_fs()) {
 #'    fname = file.path(fs_subj_dir(), "bert", "surf", "lh.thickness")
 #'    out = surf_convert(fname)
 #' }
 surf_convert = function(
-  file, 
-  outfile = NULL){
-  
+  file,
+  outfile = NULL,
+  ...
+) {
   if (is.null(outfile)) {
     outfile = tempfile(fileext = ".dat")
   }
@@ -25,9 +27,11 @@ surf_convert = function(
     frontopts = opts,
     retimg = FALSE,
     samefile = FALSE,
-    add_ext = FALSE)
+    add_ext = FALSE,
+    ...
+  )
   stopifnot(res == 0)
-  
+
   ###############################
   # Reading the data back in
   ###############################
@@ -38,6 +42,6 @@ surf_convert = function(
   rl = do.call("rbind", rl)
   class(rl) = "numeric"
   colnames(rl) = c("col", "row", "slice", "frame", "value")
-  
+
   return(rl)
-}
\ No newline at end of file
+}
